@@ -20,27 +20,59 @@
 get_ipc <- function(folder = tempdir()){
 
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
+  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   suppressMessages({
     u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=2e92084a-94ec-4fec-b5ca-42b40d5d2826&groupId=10181"
     f <- fs::path(folder, "IPC gral var M_B10.xls")
-    try(utils::download.file(u, f, mode = "wb", method = "libcurl"))
-    df <- readxl::read_xls(f)
-    df <- df %>% dplyr::slice(7, 10:999)
+    if (identical(.Platform$OS.type, "windows")) {
+      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+    } else {
+      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+    }
+    df <- readxl::read_xls(f) %>%
+      dplyr::slice(7, 10:999)
     names(df) <- df[1,]
     df <- df[-1,]
-    df <- janitor::clean_names(df)
-    df <- df %>%
-      dplyr::mutate(fecha = janitor::excel_numeric_to_date(as.numeric(as.character(.data$mes_y_ano)), date_system = "modern"))
-    df <- df %>% dplyr::select(.data$fecha, dplyr::everything(), -.data$mes_y_ano)
+    df <- janitor::clean_names(df) %>%
+      dplyr::mutate(fecha = janitor::excel_numeric_to_date(as.numeric(as.character(.data$mes_y_ano)), date_system = "modern")) %>%
+      dplyr::select(.data$fecha, dplyr::everything(), -.data$mes_y_ano)
     ipc_base2010 <- df
   })
 }
 
+#' This function allows you to organize dates
+#' @family utils
+#' @param data data frame with an 'yy' variable for the year, and a 'mm' variable for the month
+#' @importFrom dplyr mutate case_when
+#' @return data.frame
+#' @export
+# @examples
+# df <- dates_ech(data = )
+
+dates_ech <- function(data) {
+  data %>% dplyr::mutate(
+    mm = dplyr::case_when(mm == "enero" ~ "01",
+                          mm == "febrero" ~ "02",
+                          mm == "marzo" ~ "03",
+                          mm == "abril" ~ "04",
+                          mm == "mayo" ~ "05",
+                          mm == "junio" ~ "06",
+                          mm == "julio" ~ "07",
+                          mm == "agosto" ~ "08",
+                          mm == "setiembre" ~ "09",
+                          mm == "octubre" ~ "10",
+                          mm == "noviembre" ~ "11",
+                          TRUE ~ "12"),
+    dd = "01",
+    fecha = as.Date(paste(yy, mm, dd, sep = "-")))
+}
+
+
 #' This function allows you to get the IPC data
 #' @family dwnld_read
 #' @param folder temporal folder
 #' @param region Montevideo ("M") or Interior ("I")
-#' @param sheet sheet number
+#' @param sheet sheet number. Default 1.
 #'
 #' @importFrom readxl read_xls
 #' @importFrom dplyr slice mutate select everything filter_all slice any_vars bind_rows
@@ -58,9 +90,9 @@ get_ipc <- function(folder = tempdir()){
 #' \donttest{
 #' get_ipc_region(folder = tempdir(), region = "M")
 #' }
-#'
-get_ipc_region <- function(folder = tempdir(), region = "M", sheet = NULL){
 
+get_ipc_region <- function(folder = tempdir(), region, sheet = 1){
+  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I"), msg = "Sorry... :( \n \t region parameter must be 'M' for Montevideo or 'I' for Interior")
   suppressMessages({
@@ -72,35 +104,22 @@ get_ipc_region <- function(folder = tempdir(), region = "M", sheet = NULL){
       u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=61f9e884-781d-44be-9760-6d69f214b5b3&groupId=10181"
       f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
     }
-
-    try(utils::download.file(u, f, mode = "wb", method = "libcurl"))
+    if (identical(.Platform$OS.type, "windows")) {
+      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+    } else {
+      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+    }
     df <- readxl::read_xls(f, sheet = sheet)
     df <- df[,-1] %>% janitor::remove_empty("rows")
-    df <- dplyr::bind_rows(slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl('ndice General', .))))
+    df <- dplyr::bind_rows(dplyr::slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl('ndice General', .))))
     names(df) <- df[1,]
     df <- df[-1,]
-    df <- df %>% dplyr::select(dplyr::contains("20"))
-    df <- janitor::clean_names(df)
-    df <- tidyr::gather(df, fecha, indice, names(df)[1]:names(df)[ncol(df)], factor_key = TRUE)
-    df <- df %>%
-      tidyr::separate(fecha, into = c("mm", "yy"), sep ="_") %>%
-      dplyr::mutate(
-        mm = dplyr::case_when(mm == "enero" ~ "01",
-                              mm == "febrero" ~ "02",
-                              mm == "marzo" ~ "03",
-                              mm == "abril" ~ "04",
-                              mm == "mayo" ~ "05",
-                              mm == "junio" ~ "06",
-                              mm == "julio" ~ "07",
-                              mm == "agosto" ~ "08",
-                              mm == "setiembre" ~ "09",
-                              mm == "octubre" ~ "10",
-                              mm == "noviembre" ~ "11",
-                              TRUE ~ "12"),
-        dd = "01",
-        fecha = as.Date(paste(yy, mm, dd, sep ="-"))
-      )
-    df <- df %>% dplyr::select(fecha, indice)
+    df <- df %>% dplyr::select(dplyr::contains("20")) %>%
+      janitor::clean_names()
+    df <- df %>% tidyr::gather(fecha, indice, names(df)[1]:names(df)[ncol(df)], factor_key = TRUE) %>%
+      tidyr::separate(fecha, into = c("mm", "yy"), sep = "_") %>%
+      ech::dates_ech() %>%
+      dplyr::select(fecha, indice)
 
     if (region == "M") {
       ipc_base2010_mdeo <- df
@@ -114,8 +133,8 @@ get_ipc_region <- function(folder = tempdir(), region = "M", sheet = NULL){
 #' This function allows you to get the CBA and CBNA data
 #' @family dwnld_read
 #' @param folder temporal folder
-#' @param sheet sheet number
 #' @param region Montevideo ("M"), Interior Urbano ("I"), Interior Rural ("R")
+#' @param sheet sheet number. Default 1.
 #'
 #' @importFrom readxl read_xls
 #' @importFrom dplyr slice mutate bind_cols
@@ -130,27 +149,29 @@ get_ipc_region <- function(folder = tempdir(), region = "M", sheet = NULL){
 #' Aviso: El script no es un producto oficial de INE.
 #'
 #' @examples
-#' get_cba_cbna(folder = tempdir(), sheet = 1, region = "M")
+#' get_cba_cbna(folder = tempdir(), region = "M")
 #'
-get_cba_cbna <- function(folder = tempdir(), sheet = NULL, region = NULL){
-
+get_cba_cbna <- function(folder = tempdir(), region, sheet = 1){
+  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg =  "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I", "R"), msg =  "Sorry... :( \n \t region parameter must be 'M' for Montevideo, 'I' for Interior urbano or 'R' for Interior rural")
   suppressMessages({
     u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=1675e7d0-6fe0-49bd-bf3f-a46bd6334c0c&groupId=10181"
-    f <- fs::path(folder, "CBA_LP_LI M.xls")
-    try(utils::download.file(u, f, mode = "wb", method = "libcurl"))
-
+    f <- fs::path(folder, "CBA_LP_LI_M.xls")
+    if (identical(.Platform$OS.type, "windows")) {
+      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+    } else {
+      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+    }
     df <- readxl::read_xls(f, sheet = sheet)
     date <- df[9:nrow(df),1]
     names(date) <- "fecha"
     date <- date %>%
       dplyr::mutate(fecha = janitor::excel_numeric_to_date(as.numeric(as.character(fecha)), date_system = "modern")) %>%
       janitor::remove_empty("rows")
-
     df <- df[,-1] %>% janitor::remove_empty("rows") %>% janitor::remove_empty("cols")
 
-    if (region == "M"){
+    if (region == "M") {
       cba_mdeo <- df[, 1:3]
       names(cba_mdeo) <- df[2, 1:3]
       cba_mdeo <- cba_mdeo %>%
@@ -158,7 +179,7 @@ get_cba_cbna <- function(folder = tempdir(), sheet = NULL, region = NULL){
         janitor::clean_names() %>%
         purrr::map_df(as.numeric) %>%
         dplyr::bind_cols(date,.)
-    } else if (region == "I"){
+    } else if (region == "I") {
       cba_int_urb <- df[, 4:6]
       names(cba_int_urb) <- df[2, 4:6]
       cba_int_urb <- cba_int_urb %>%
@@ -182,7 +203,7 @@ get_cba_cbna <- function(folder = tempdir(), sheet = NULL, region = NULL){
 #' This function allows you to get the IPAB (Indice de precios de alimentos y bebidas) data
 #' @family dwnld_read
 #' @param folder temporal folder
-#' @param sheet sheet number
+#' @param sheet sheet number. Default 1
 #' @importFrom readxl read_xls
 #' @importFrom janitor remove_empty
 #' @importFrom dplyr bind_rows slice filter_all bind_cols any_vars mutate_all
@@ -194,49 +215,39 @@ get_cba_cbna <- function(folder = tempdir(), sheet = NULL, region = NULL){
 #' Aviso: El script no es un producto oficial de INE.
 #'
 #' @examples
-#' get_ipab(folder = tempdir(), sheet = 1)
-
-get_ipab <- function(folder = tempdir(), sheet = NULL){
+#' get_ipab(folder = tempdir())
 
+get_ipab <- function(folder = tempdir(), sheet = 1){
+  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg =  "Sorry... :( \n \t folder parameter must be character")
   suppressMessages({
     u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=c4b5efaa-cdd4-497a-ab78-e3138e4f08dc&groupId=10181"
     f <- fs::path(folder, "IPC Div M_B10.xls")
-    try(utils::download.file(u, f, mode = "wb", method = "libcurl"))
-
+    if (identical(.Platform$OS.type, "windows")) {
+      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+    } else {
+      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+    }
     df <- readxl::read_xls(f, sheet = sheet)
     df <- df[,-1:-2] %>% janitor::remove_empty("rows")
     df <- dplyr::bind_rows(dplyr::slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl(c('Divisiones'), .))), dplyr::filter_all(df, dplyr::any_vars(grepl(c('Alimentos y Bebidas No Alcoh'), .))))
-    df [,1] <- c("yy", "mm", "indice")
+    df[,1] <- c("yy", "mm", "indice")
     df <- dplyr::bind_cols(t(df[1,]), t(df[2,]), t(df[3,]))
     names(df) <- df[1,]
-    df <- df %>% dplyr::slice(-1) %>% janitor::remove_empty("rows")
-    df <- df %>% tidyr::fill(yy)
-    df <- df %>% dplyr::mutate_all(tolower) %>%
-      dplyr::mutate(
-        mm = dplyr::case_when(mm == "ene" ~ "01",
-                              mm == "feb" ~ "02",
-                              mm == "mar" ~ "03",
-                              mm == "abr" ~ "04",
-                              mm == "may" ~ "05",
-                              mm == "jun" ~ "06",
-                              mm == "jul" ~ "07",
-                              mm == "ago" ~ "08",
-                              mm == "set" ~ "09",
-                              mm == "oct" ~ "10",
-                              mm == "nov" ~ "11",
-                              TRUE ~ "12"),
-        dd = "01",
-        fecha = as.Date(paste(yy, mm, dd, sep ="-"))
-      ) %>% dplyr::select(fecha, indice)
+    df <- df %>% dplyr::slice(-1) %>%
+      janitor::remove_empty("rows") %>%
+      tidyr::fill(yy) %>%
+      dplyr::mutate_all(tolower) %>%
+      ech::dates_ech() %>%
+      dplyr::select(fecha, indice)
   })
 }
 
 #' This function allows you to get the IPAB (Indice de precios de alimentos y bebidas) data
 #' @family dwnld_read
 #' @param folder temporal folder
-#' @param sheet sheet number
 #' @param region Montevideo ("M"), Interior Urbano ("I")
+#' @param sheet sheet number. Default 1
 #' @importFrom readxl read_xls
 #' @importFrom janitor remove_empty
 #' @importFrom dplyr bind_rows slice filter_all bind_cols any_vars mutate
@@ -245,10 +256,10 @@ get_ipab <- function(folder = tempdir(), sheet = NULL){
 #' @export
 #'
 #' @examples
-#' get_ipab_region(folder = tempdir(), sheet = 1, region = "M")
+#' get_ipab_region(folder = tempdir(), region = "M")
 #'
-get_ipab_region <- function(folder = tempdir(), sheet = NULL, region = "M"){
-
+get_ipab_region <- function(folder = tempdir(), region, sheet = 1){
+  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I"), msg = "Sorry... :( \n \t region parameter must be 'M' for Montevideo or 'I' for Interior")
   suppressMessages({
@@ -259,8 +270,11 @@ get_ipab_region <- function(folder = tempdir(), sheet = NULL, region = "M"){
       u <- "http://ine.gub.uy/c/document_library/get_file?uuid=61f9e884-781d-44be-9760-6d69f214b5b3&groupId=10181"
       f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
     }
-
-    try(utils::download.file(u, f, mode = "wb", method = "libcurl"))
+    if (identical(.Platform$OS.type, "windows")) {
+      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+    } else {
+      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+    }
     df <- readxl::read_xls(f, sheet = sheet)
     df <- df[,-1] %>% janitor::remove_empty("rows")
     df <- dplyr::bind_rows(dplyr::slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl(c('Alimentos y Bebidas No Alcoh'), .))))
@@ -268,26 +282,12 @@ get_ipab_region <- function(folder = tempdir(), sheet = NULL, region = "M"){
     df <- df %>% janitor::remove_empty("cols")
     df <- df[,-1]
     df <- t(df)
-    df <- data.frame(df)
-    df <- df %>% tidyr::drop_na()
-    df <- df %>% tidyr::separate(X1, sep = " ", into = c("mm", "yy"))
+    df <- data.frame(df) %>%
+      tidyr::drop_na() %>%
+      tidyr::separate(X1, sep = " ", into = c("mm", "yy"))
     names(df) <- c("mm", "yy", "indice")
     df <- df %>% dplyr::mutate_all(tolower) %>%
-      dplyr::mutate(
-        mm = dplyr::case_when(mm == "enero" ~ "01",
-                              mm == "febrero" ~ "02",
-                              mm == "marzo" ~ "03",
-                              mm == "abril" ~ "04",
-                              mm == "mayo" ~ "05",
-                              mm == "junio" ~ "06",
-                              mm == "julio" ~ "07",
-                              mm == "agosto" ~ "08",
-                              mm == "setiembre" ~ "09",
-                              mm == "octubre" ~ "10",
-                              mm == "noviembre" ~ "11",
-                              TRUE ~ "12"),
-        dd = "01",
-        fecha = as.Date(paste(yy, mm, dd, sep ="-"))) %>%
+      ech::dates_ech() %>%
       dplyr::select(fecha, indice)
 
     if (region == "M") {
@@ -315,10 +315,14 @@ get_ciiu <- function(folder = tempdir(),
                      version = 4){
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(is.numeric(version), msg = "Sorry... :( \n \t version parameter must be numeric")
-
+  attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   u <- "http://www.ine.gub.uy/documents/10181/33330/CORRESPONDENCIA+CIUU4+A+CIUU3.pdf/623c43cb-009c-4da9-b48b-45282745063b"
   f <- fs::path(folder, "ciiu4.pdf")
-  try(utils::download.file(u, f, mode = "wb", method = "libcurl"))
+  if (identical(.Platform$OS.type, "windows")) {
+    utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+  } else {
+    utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+  }
   key <- rstudioapi::askForSecret("api_key")
   pdftables::convert_pdf(f, "ciiu4.csv",api_key = key)
   df <- read.csv("ciiu4.csv")
@@ -356,19 +360,19 @@ deflate <- function(base_month = NULL,
   assertthat::assert_that(level %in% c("G", "M", "I"), msg = "Sorry... :( \n \t level parameter must be 'G' for General, 'M' for Montevideo or 'I' for Interior")
   assertthat::assert_that(index %in% c("IPC", "IPAB"), msg = "Sorry... :( \n \t index parameter must be 'IPC' or 'IPAB'")
 
-  if (nchar(as.character(base_month)) == 1){
+  if (nchar(as.character(base_month)) == 1) {
     base_month <- paste0("0", base_month)
   }
 
   if (index == "IPC" & level == "G") {
     df <- ech::ipc_base2010
-  }  else if (index == "IPC" & level == "M"){
+  }  else if (index == "IPC" & level == "M") {
     df <- ech::ipc_base2010_mdeo
-  } else if (index == "IPC" & level == "I"){
+  } else if (index == "IPC" & level == "I") {
     df <- ech::ipc_base2010_int
-  } else if (index == "IPAB" & level == "G"){
+  } else if (index == "IPAB" & level == "G") {
     df <- ech::ipab_base2010
-  }  else if (index == "IPAB" & level == "M"){
+  }  else if (index == "IPAB" & level == "M") {
     df <- ech::ipab_base2010_mdeo
   } else {
     df <- ech::ipab_base2010_int
@@ -459,14 +463,14 @@ age_groups <- function(data = ech::toy_ech_2018,
   assertthat::assert_that(is.numeric(cut), msg = glue:glue("Sorry... :( \n \t cut parameter must be a numeric vector"))
   assertthat::assert_that(e27 %in% names(data), msg =  glue:glue("Sorry... :( \n \t {e27} is not in data"))
 
-  if (min(dplyr::pull(data[, e27])) < min(cut)){
+  if (min(dplyr::pull(data[, e27])) < min(cut)) {
     cut <- c(min(dplyr::pull(data[, e27])), cut)
   }
-  if (max(dplyr::pull(data[, e27])) > max(cut)){
+  if (max(dplyr::pull(data[, e27])) > max(cut)) {
     cut <- c(cut, max(dplyr::pull(data[, e27])))
   }
 
-  data <- data %>% dplyr::mutate(age_groups = cut(e27, breaks = cut, include.lowest = TRUE, ordered_result = TRUE, labels =FALSE),
+  data <- data %>% dplyr::mutate(age_groups = cut(e27, breaks = cut, include.lowest = TRUE, ordered_result = TRUE, labels = FALSE),
                                  age_groups = haven::labelled(age_groups, label = "Grupos de edad"))
 
   return(data)
@@ -489,7 +493,7 @@ organize_ht11 <- function(data = ech::toy_ech_2018,
                           ht11 = "ht11",
                           numero = "numero"){
 
-  if(year %in% 2013:2015){
+  if (year %in% 2013:2015) {
     data <- data %>%
       dplyr::group_by(numero) %>%
       dplyr::mutate(ht11 = max(ht11)) %>%
@@ -508,3 +512,20 @@ organize_ht11 <- function(data = ech::toy_ech_2018,
 #' @usage lhs \%>\% rhs
 NULL
 
+#' add_geom
+#' See \code{geouy::\link[geouy]{add_geom}} for details.
+#' @name add_geom
+#' @rdname add_geom
+#' @keywords internal
+#' @export
+#' @importFrom geouy add_geom
+NULL
+
+#' plot_geouy
+#' See \code{geouy::\link[geouy]{plot_geouy}} for details.
+#' @name plot_geouy
+#' @rdname plot_geouy
+#' @keywords internal
+#' @export
+#' @importFrom geouy plot_geouy
+NULL
